# Tracé d'un graphe donnant le pourcentage de prédominance des formes acide et basique d'un couple
import matplotlib.pyplot as plt
import numpy as np
import matplotlib.ticker as mtick#Format pourcentage

#Paramètres à personnaliser
pKa=5
pHmin=0
pHmax=14
#autre proposition de réglage :
#pHmin=pKa-2
#pHmax=pKa+2

fig, ax=plt.subplots()
pH=np.arange(pHmin, pHmax, 0.1)

#D'après la formule pH=pKa + log [base]/[acide] :
acide=100/(1+10**(pH-pKa))
base=100*10**(pH-pKa)/(1+10**(pH-pKa))

plt.plot(pH, acide, label='forme acide')
plt.plot(pH, base, label='forme basique')
plt.legend()
plt.xlabel('pH')
plt.title(r"Prédominance des formes d'un couple acide/base")

#traits de lecture du pKa
plt.plot([pHmin, pKa], [50, 50], 'r--')
plt.plot([pKa, pKa], [50, 0], 'r--')
plt.text(pHmin+1, 20, r'pKa= %s' %(pKa), backgroundcolor='white', color='red',  fontsize=14)

#Réglages des espaces de graduations des axes :
plt.yticks(np.arange(0, 100, 10))
#plt.xticks(np.arange(0, 14, 2.0))

#réglage perso de la grille secondaire :
minor_xticks = np.arange(0, 14, 1)#grille secondaire en x
minor_yticks = np.arange(0, 101, 5)#grille secondaire en y
ax.set_xticks(minor_xticks, minor=True)
ax.set_yticks(minor_yticks, minor=True)
ax.grid(which='minor', alpha=0.5)

ax.yaxis.set_major_formatter(mtick.PercentFormatter(symbol= ' %'))

plt.axis([pHmin, pHmax, 0, 105])#limites des axes

plt.grid()

plt.show()
